@@ -184,9 +184,6 @@ private Q_SLOTS:
 
     void testMoveFolder()
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 8, 1)
-        QSKIP("This test requires fixes in QSFPM, QIPM (which were made in Qt 5.8.1)");
-#endif
         // Given a source folder with 2 levels of parents (res1/sub1/sub2)
         const QStringList folderNames = collectNames(mCollectionModel);
         const QModelIndex res1Index = mCollectionModel->index(folderNames.indexOf("res1"), 0, QModelIndex());
