@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,29 +26,26 @@ public:
     TestFilterActionWithAddress()
         : MailCommon::FilterActionWithAddress(QStringLiteral("foo"), QStringLiteral("bla"))
     {
-
     }
-    FilterAction::ReturnCode process(MailCommon::ItemContext &, bool) const Q_DECL_OVERRIDE
+
+    FilterAction::ReturnCode process(MailCommon::ItemContext &, bool) const override
     {
         return GoOn;
     }
 
-    MailCommon::SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE
+    MailCommon::SearchRule::RequiredPart requiredPart() const override
     {
         return MailCommon::SearchRule::CompleteMessage;
     }
-
 };
 
 FilterActionWithAddressTest::FilterActionWithAddressTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FilterActionWithAddressTest::~FilterActionWithAddressTest()
 {
-
 }
 
 void FilterActionWithAddressTest::shouldHaveDefaultValue()
