@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -135,7 +135,7 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     //----------- the first row of buttons
     QWidget *hb = new QWidget(this);
     QHBoxLayout *hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hbHBoxLayout->setSpacing(4);
 
     mBtnTop = new QPushButton(QString(), hb);
@@ -177,7 +177,7 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     //----------- the second row of buttons
     hb = new QWidget(this);
     hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hbHBoxLayout->setSpacing(4);
     mBtnNew = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnNew);
@@ -381,7 +381,7 @@ void KMFilterListBox::applyFilterChanged(bool closeAfterSaving)
 
 QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, bool &wasCanceled) const
 {
-    const_cast<KMFilterListBox *>(this)->applyWidgets();  // signals aren't const
+    Q_EMIT const_cast<KMFilterListBox *>(this)->applyWidgets();  // signals aren't const
     QList<MailFilter *> filters;
     QStringList emptyFilters;
     QVector<MailCommon::InvalidFilterInfo> listInvalidFilters;
