@@ -24,11 +24,10 @@
 #include <KLineEdit>
 #include <QIcon>
 #include <QUrl>
+#include <QMediaPlayer>
 
 #include <QHBoxLayout>
 #include <QPushButton>
-
-#include <phonon/mediaobject.h>
 #include <QStandardPaths>
 
 using namespace MailCommon;
@@ -37,7 +36,7 @@ SoundTestWidget::SoundTestWidget(QWidget *parent)
     : QWidget(parent)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     m_playButton = new QPushButton(this);
     m_playButton->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
@@ -113,9 +112,15 @@ void SoundTestWidget::playSound()
     const QString play = (parameter.startsWith(file)
                           ? parameter.mid(file.length())
                           : parameter);
-    Phonon::MediaObject *player = Phonon::createPlayer(Phonon::NotificationCategory, QUrl::fromLocalFile(play));
+    QMediaPlayer *player = new QMediaPlayer;
+    player->setMedia(QUrl::fromLocalFile(play));
+    player->setVolume(50);
+    connect(player, &QMediaPlayer::stateChanged, this, [this, player](QMediaPlayer::State state) {
+        if (state == QMediaPlayer::StoppedState) {
+            player->deleteLater();
+        }
+    });
     player->play();
-    connect(player, &Phonon::MediaObject::finished, player, &Phonon::MediaObject::deleteLater);
 }
 
 QString SoundTestWidget::url() const
