@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -85,7 +85,8 @@ void FillTagComboJob::onTagsFetched(KJob *job)
         return;
     }
     Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
-    foreach (const Akonadi::Tag &tag, fetchJob->tags()) {
+    const auto lst = fetchJob->tags();
+    for (const Akonadi::Tag &tag : lst) {
         QString iconName = QStringLiteral("mail-tagged");
         Akonadi::TagAttribute *attr = tag.attribute<Akonadi::TagAttribute>();
         if (attr) {
